Class: Google::Apis::SecretmanagerV1::ManagedRotationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb

Overview

Represents the status of a managed rotation. This is applicable only to Typed Secrets. It indicates whether the rotation is active and any errors that may have occurred during the asynchronous managed rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedRotationStatus

Returns a new instance of ManagedRotationStatus.



676
677
678
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::SecretmanagerV1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



669
670
671
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 669

def error
  @error
end

#stateString

Output only. Indicates whether the Managed Rotation is active or not. Corresponds to the JSON property state

Returns:

  • (String)


674
675
676
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 674

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



681
682
683
684
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 681

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end