Class: Google::Apis::SecretmanagerV1::Replication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb

Overview

A policy that defines the replication and encryption configuration of data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Replication

Returns a new instance of Replication.



886
887
888
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automaticGoogle::Apis::SecretmanagerV1::Automatic

A replication policy that replicates the Secret payload without any restrictions. Corresponds to the JSON property automatic



878
879
880
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 878

def automatic
  @automatic
end

#user_managedGoogle::Apis::SecretmanagerV1::UserManaged

A replication policy that replicates the Secret payload into the locations specified in Replication.UserManaged.replicas Corresponds to the JSON property userManaged



884
885
886
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 884

def user_managed
  @user_managed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



891
892
893
894
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 891

def update!(**args)
  @automatic = args[:automatic] if args.key?(:automatic)
  @user_managed = args[:user_managed] if args.key?(:user_managed)
end