Class: Google::Apis::SecretmanagerV1::SecretManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::SecretmanagerV1::SecretManagerService
- Defined in:
- lib/google/apis/secretmanager_v1/service.rb
Overview
Secret Manager API
Stores sensitive data such as API keys, passwords, and certificates. Provides convenience while improving security.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://secretmanager.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#access_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion.
-
#access_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion.
-
#add_project_location_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
-
#add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
-
#create_project_location_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
-
#create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
-
#delete_project_location_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
-
#delete_project_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
-
#destroy_project_location_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion.
-
#destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion.
-
#disable_project_location_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion.
-
#disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion.
-
#enable_project_location_secret_managed_rotation(parent, enable_managed_rotation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables the managed rotation feature for a Secret.
-
#enable_project_location_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion.
-
#enable_project_secret_managed_rotation(parent, enable_managed_rotation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables the managed rotation feature for a Secret.
-
#enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Location
Gets information about a location.
-
#get_project_location_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
-
#get_project_location_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret.
-
#get_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion.
-
#get_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
-
#get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret.
-
#get_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion.
-
#initialize ⇒ SecretManagerService
constructor
A new instance of SecretManagerService.
-
#list_project_location_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions.
-
#list_project_location_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions.
-
#list_project_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
-
#patch_project_location_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
-
#patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
-
#rotate_project_location_secret_secret(parent, rotate_secret_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Do a managed rotation for a Secret.
-
#rotate_project_secret_secret(parent, rotate_secret_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Do a managed rotation for a Secret.
-
#set_project_location_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret.
-
#set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret.
-
#test_project_location_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret.
-
#test_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret.
Constructor Details
#initialize ⇒ SecretManagerService
Returns a new instance of SecretManagerService.
48 49 50 51 52 53 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-secretmanager_v1', client_version: Google::Apis::SecretmanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#access_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion. This call returns the secret data. projects/*/
secrets/*/versions/latest is an alias to the most recently created
SecretVersion.
583 584 585 586 587 588 589 590 591 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 583 def access_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:access', ) command.response_representation = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#access_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion. This call returns the secret data. projects/*/
secrets/*/versions/latest is an alias to the most recently created
SecretVersion.
1222 1223 1224 1225 1226 1227 1228 1229 1230 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1222 def access_project_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:access', ) command.response_representation = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_project_location_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 164 def add_project_location_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:addVersion', ) command.request_representation = Google::Apis::SecretmanagerV1::AddSecretVersionRequest::Representation command.request_object = add_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
803 804 805 806 807 808 809 810 811 812 813 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 803 def add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:addVersion', ) command.request_representation = Google::Apis::SecretmanagerV1::AddSecretVersionRequest::Representation command.request_object = add_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 202 def create_project_location_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/secrets', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['parent'] = parent unless parent.nil? command.query['secretId'] = secret_id unless secret_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 841 def create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/secrets', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['parent'] = parent unless parent.nil? command.query['secretId'] = secret_id unless secret_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
240 241 242 243 244 245 246 247 248 249 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 240 def delete_project_location_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Empty::Representation command.response_class = Google::Apis::SecretmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
879 880 881 882 883 884 885 886 887 888 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 879 def delete_project_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Empty::Representation command.response_class = Google::Apis::SecretmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#destroy_project_location_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion. Sets the state of the SecretVersion to DESTROYED and irrevocably destroys the secret data.
617 618 619 620 621 622 623 624 625 626 627 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 617 def destroy_project_location_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:destroy', ) command.request_representation = Google::Apis::SecretmanagerV1::DestroySecretVersionRequest::Representation command.request_object = destroy_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion. Sets the state of the SecretVersion to DESTROYED and irrevocably destroys the secret data.
1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1256 def destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:destroy', ) command.request_representation = Google::Apis::SecretmanagerV1::DestroySecretVersionRequest::Representation command.request_object = destroy_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_project_location_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion. Sets the state of the SecretVersion to DISABLED.
652 653 654 655 656 657 658 659 660 661 662 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 652 def disable_project_location_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:disable', ) command.request_representation = Google::Apis::SecretmanagerV1::DisableSecretVersionRequest::Representation command.request_object = disable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion. Sets the state of the SecretVersion to DISABLED.
1291 1292 1293 1294 1295 1296 1297 1298 1299 1300 1301 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1291 def disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:disable', ) command.request_representation = Google::Apis::SecretmanagerV1::DisableSecretVersionRequest::Representation command.request_object = disable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_project_location_secret_managed_rotation(parent, enable_managed_rotation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables the managed rotation feature for a Secret. This method can only be triggered once for a secret. In order to do further rotations, RotateSecret should be used. This method will add a secret version and update the password in Cloud SQL.
276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 276 def enable_project_location_secret_managed_rotation(parent, enable_managed_rotation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:enableManagedRotation', ) command.request_representation = Google::Apis::SecretmanagerV1::EnableManagedRotationRequest::Representation command.request_object = enable_managed_rotation_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_project_location_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion. Sets the state of the SecretVersion to ENABLED.
687 688 689 690 691 692 693 694 695 696 697 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 687 def enable_project_location_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enable', ) command.request_representation = Google::Apis::SecretmanagerV1::EnableSecretVersionRequest::Representation command.request_object = enable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_project_secret_managed_rotation(parent, enable_managed_rotation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables the managed rotation feature for a Secret. This method can only be triggered once for a secret. In order to do further rotations, RotateSecret should be used. This method will add a secret version and update the password in Cloud SQL.
915 916 917 918 919 920 921 922 923 924 925 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 915 def enable_project_secret_managed_rotation(parent, enable_managed_rotation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:enableManagedRotation', ) command.request_representation = Google::Apis::SecretmanagerV1::EnableManagedRotationRequest::Representation command.request_object = enable_managed_rotation_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion. Sets the state of the SecretVersion to ENABLED.
1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1326 def enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enable', ) command.request_representation = Google::Apis::SecretmanagerV1::EnableSecretVersionRequest::Representation command.request_object = enable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Location::Representation command.response_class = Google::Apis::SecretmanagerV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
309 310 311 312 313 314 315 316 317 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 309 def get_project_location_secret(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret. Returns empty policy if the secret exists and does not have a policy set.
353 354 355 356 357 358 359 360 361 362 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 353 def get_project_location_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion. projects/*/secrets/*/versions/latest is
an alias to the most recently created SecretVersion.
723 724 725 726 727 728 729 730 731 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 723 def get_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
948 949 950 951 952 953 954 955 956 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 948 def get_project_secret(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret. Returns empty policy if the secret exists and does not have a policy set.
992 993 994 995 996 997 998 999 1000 1001 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 992 def get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion. projects/*/secrets/*/versions/latest is
an alias to the most recently created SecretVersion.
1362 1363 1364 1365 1366 1367 1368 1369 1370 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1362 def get_project_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions. This call does not return secret data.
767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 767 def list_project_location_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/versions', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 396 def list_project_location_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/secrets', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 127 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::SecretmanagerV1::ListLocationsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions. This call does not return secret data.
1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1406 def list_project_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/versions', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1035 def list_project_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/secrets', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 433 def patch_project_location_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1072 def patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rotate_project_location_secret_secret(parent, rotate_secret_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Do a managed rotation for a Secret. This can only be triggered after Managed rotation has been enabled. This method will add a secret version and update the password in Cloud SQL.
470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 470 def rotate_project_location_secret_secret(parent, rotate_secret_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:rotateSecret', ) command.request_representation = Google::Apis::SecretmanagerV1::RotateSecretRequest::Representation command.request_object = rotate_secret_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rotate_project_secret_secret(parent, rotate_secret_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Do a managed rotation for a Secret. This can only be triggered after Managed rotation has been enabled. This method will add a secret version and update the password in Cloud SQL.
1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1109 def rotate_project_secret_secret(parent, rotate_secret_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:rotateSecret', ) command.request_representation = Google::Apis::SecretmanagerV1::RotateSecretRequest::Representation command.request_object = rotate_secret_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret. Replaces any existing policy. Permissions on SecretVersions are enforced according to the policy set on the associated Secret.
507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 507 def set_project_location_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::SecretmanagerV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret. Replaces any existing policy. Permissions on SecretVersions are enforced according to the policy set on the associated Secret.
1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1146 def set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::SecretmanagerV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret. If the secret does not exist, this call returns an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission- aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 546 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret. If the secret does not exist, this call returns an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission- aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1185 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |