Class: Google::Apis::SecretmanagerV1::SecretPayload
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1::SecretPayload
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb
Overview
A secret payload resource in the Secret Manager API. This contains the sensitive secret payload that is associated with a SecretVersion.
Instance Attribute Summary collapse
-
#data ⇒ String
The secret data.
-
#data_crc32c ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretPayload
constructor
A new instance of SecretPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretPayload
Returns a new instance of SecretPayload.
1110 1111 1112 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ String
The secret data. Must be no larger than 64KiB.
Corresponds to the JSON property data
NOTE: Values are automatically base64 encoded/decoded in the client library.
1095 1096 1097 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1095 def data @data end |
#data_crc32c ⇒ Fixnum
Optional. If specified, SecretManagerService will verify the integrity of the
received data on SecretManagerService.AddSecretVersion calls using the crc32c
checksum and store it to include in future SecretManagerService.
AccessSecretVersion responses. If a checksum is not provided in the
SecretManagerService.AddSecretVersion request, the SecretManagerService will
generate and store one for you. The CRC32C value is encoded as a Int64 for
compatibility, and can be safely downconverted to uint32 in languages that
support this type. https://cloud.google.com/apis/design/design_patterns#
integer_types
Corresponds to the JSON property dataCrc32c
1108 1109 1110 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1108 def data_crc32c @data_crc32c end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1115 1116 1117 1118 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1115 def update!(**args) @data = args[:data] if args.key?(:data) @data_crc32c = args[:data_crc32c] if args.key?(:data_crc32c) end |