Class: Google::Apis::SecretmanagerV1::SecretVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb

Overview

A secret version resource in the Secret Manager API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecretVersion

Returns a new instance of SecretVersion.



1375
1376
1377
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_specified_payload_checksumBoolean Also known as: client_specified_payload_checksum?

Output only. True if payload checksum specified in SecretPayload object has been received by SecretManagerService on SecretManagerService.AddSecretVersion. Corresponds to the JSON property clientSpecifiedPayloadChecksum

Returns:

  • (Boolean)


1325
1326
1327
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1325

def client_specified_payload_checksum
  @client_specified_payload_checksum
end

#create_timeString

Output only. The time at which the SecretVersion was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1331
1332
1333
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1331

def create_time
  @create_time
end

#customer_managed_encryptionGoogle::Apis::SecretmanagerV1::CustomerManagedEncryptionStatus

Describes the status of customer-managed encryption. Corresponds to the JSON property customerManagedEncryption



1336
1337
1338
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1336

def customer_managed_encryption
  @customer_managed_encryption
end

#destroy_timeString

Output only. The time this SecretVersion was destroyed. Only present if state is DESTROYED. Corresponds to the JSON property destroyTime

Returns:

  • (String)


1342
1343
1344
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1342

def destroy_time
  @destroy_time
end

#etagString

Output only. Etag of the currently stored SecretVersion. Corresponds to the JSON property etag

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1347

def etag
  @etag
end

#nameString

Output only. The resource name of the SecretVersion in the format projects/*/ secrets/*/versions/*. SecretVersion IDs in a Secret start at 1 and are incremented for each subsequent version of the secret. Corresponds to the JSON property name

Returns:

  • (String)


1354
1355
1356
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1354

def name
  @name
end

#replication_statusGoogle::Apis::SecretmanagerV1::ReplicationStatus

The replication status of a SecretVersion. Corresponds to the JSON property replicationStatus



1359
1360
1361
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1359

def replication_status
  @replication_status
end

#scheduled_destroy_timeString

Optional. Output only. Scheduled destroy time for secret version. This is a part of the Delayed secret version destroy feature. For a Secret with a valid version destroy TTL, when a secert version is destroyed, version is moved to disabled state and it is scheduled for destruction Version is destroyed only after the scheduled_destroy_time. Corresponds to the JSON property scheduledDestroyTime

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1368

def scheduled_destroy_time
  @scheduled_destroy_time
end

#stateString

Output only. The current state of the SecretVersion. Corresponds to the JSON property state

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1373

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1380

def update!(**args)
  @client_specified_payload_checksum = args[:client_specified_payload_checksum] if args.key?(:client_specified_payload_checksum)
  @create_time = args[:create_time] if args.key?(:create_time)
  @customer_managed_encryption = args[:customer_managed_encryption] if args.key?(:customer_managed_encryption)
  @destroy_time = args[:destroy_time] if args.key?(:destroy_time)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @replication_status = args[:replication_status] if args.key?(:replication_status)
  @scheduled_destroy_time = args[:scheduled_destroy_time] if args.key?(:scheduled_destroy_time)
  @state = args[:state] if args.key?(:state)
end