Class: Google::Apis::SecretmanagerV1::Topic

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb

Overview

A Pub/Sub topic which Secret Manager will publish to when control plane events occur on this secret.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Topic

Returns a new instance of Topic.



1343
1344
1345
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Identifier. The resource name of the Pub/Sub topic that will be published to, in the following format: projects/*/topics/*. For publication to succeed, the Secret Manager service agent must have the pubsub.topic.publish permission on the topic. The Pub/Sub Publisher role (roles/pubsub.publisher) includes this permission. Corresponds to the JSON property name

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1341

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1348
1349
1350
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1348

def update!(**args)
  @name = args[:name] if args.key?(:name)
end