Class: Google::Apis::SecretmanagerV1::Rotation
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1::Rotation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb
Overview
The rotation time and period for a Secret. At next_rotation_time, Secret Manager will send a Pub/Sub notification to the topics configured on the Secret. Secret.topics must be set to configure rotation.
Instance Attribute Summary collapse
-
#managed_rotation_status ⇒ Google::Apis::SecretmanagerV1::ManagedRotationStatus
Represents the status of a managed rotation.
-
#next_rotation_time ⇒ String
Optional.
-
#rotation_period ⇒ String
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rotation
constructor
A new instance of Rotation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rotation
Returns a new instance of Rotation.
1126 1127 1128 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#managed_rotation_status ⇒ Google::Apis::SecretmanagerV1::ManagedRotationStatus
Represents the status of a managed rotation. This is applicable only to Typed
Secrets. It indicates whether the rotation is active and any errors that may
have occurred during the asynchronous managed rotation.
Corresponds to the JSON property managedRotationStatus
1108 1109 1110 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1108 def managed_rotation_status @managed_rotation_status end |
#next_rotation_time ⇒ String
Optional. Timestamp in UTC at which the Secret is scheduled to rotate. Cannot
be set to less than 300s (5 min) in the future and at most 3153600000s (100
years). next_rotation_time MUST be set if rotation_period is set.
Corresponds to the JSON property nextRotationTime
1115 1116 1117 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1115 def next_rotation_time @next_rotation_time end |
#rotation_period ⇒ String
Input only. The Duration between rotation notifications. Must be in seconds
and at least 3600s (1h) and at most 3153600000s (100 years). If
rotation_period is set, next_rotation_time must be set. next_rotation_time
will be advanced by this period when the service automatically sends rotation
notifications.
Corresponds to the JSON property rotationPeriod
1124 1125 1126 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1124 def rotation_period @rotation_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1131 1132 1133 1134 1135 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1131 def update!(**args) @managed_rotation_status = args[:managed_rotation_status] if args.key?(:managed_rotation_status) @next_rotation_time = args[:next_rotation_time] if args.key?(:next_rotation_time) @rotation_period = args[:rotation_period] if args.key?(:rotation_period) end |