Class: Google::Apis::SecretmanagerV1::Rotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb

Overview

The rotation time and period for a Secret. At next_rotation_time, Secret Manager will send a Pub/Sub notification to the topics configured on the Secret. Secret.topics must be set to configure rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rotation

Returns a new instance of Rotation.



946
947
948
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_rotation_timeString

Optional. Timestamp in UTC at which the Secret is scheduled to rotate. Cannot be set to less than 300s (5 min) in the future and at most 3153600000s (100 years). next_rotation_time MUST be set if rotation_period is set. Corresponds to the JSON property nextRotationTime

Returns:

  • (String)


935
936
937
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 935

def next_rotation_time
  @next_rotation_time
end

#rotation_periodString

Input only. The Duration between rotation notifications. Must be in seconds and at least 3600s (1h) and at most 3153600000s (100 years). If rotation_period is set, next_rotation_time must be set. next_rotation_time will be advanced by this period when the service automatically sends rotation notifications. Corresponds to the JSON property rotationPeriod

Returns:

  • (String)


944
945
946
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 944

def rotation_period
  @rotation_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



951
952
953
954
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 951

def update!(**args)
  @next_rotation_time = args[:next_rotation_time] if args.key?(:next_rotation_time)
  @rotation_period = args[:rotation_period] if args.key?(:rotation_period)
end