Class: Google::Apis::SecretmanagerV1::SecretManagerService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::SecretmanagerV1::SecretManagerService
- Defined in:
- lib/google/apis/secretmanager_v1/service.rb
Overview
Secret Manager API
Stores sensitive data such as API keys, passwords, and certificates. Provides convenience while improving security.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://secretmanager.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#access_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion.
-
#access_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion.
-
#add_project_location_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
-
#add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
-
#create_project_location_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
-
#create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
-
#delete_project_location_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
-
#delete_project_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
-
#destroy_project_location_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion.
-
#destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion.
-
#disable_project_location_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion.
-
#disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion.
-
#enable_project_location_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion.
-
#enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Location
Gets information about a location.
-
#get_project_location_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
-
#get_project_location_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret.
-
#get_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion.
-
#get_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
-
#get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret.
-
#get_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion.
-
#initialize ⇒ SecretManagerService
constructor
A new instance of SecretManagerService.
-
#list_project_location_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions.
-
#list_project_location_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_project_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions.
-
#list_project_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
-
#patch_project_location_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
-
#patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
-
#set_project_location_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret.
-
#set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret.
-
#test_project_location_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret.
-
#test_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret.
Constructor Details
#initialize ⇒ SecretManagerService
Returns a new instance of SecretManagerService.
48 49 50 51 52 53 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-secretmanager_v1', client_version: Google::Apis::SecretmanagerV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#access_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion. This call returns the secret data. projects/*/
secrets/*/versions/latest is an alias to the most recently created
SecretVersion.
505 506 507 508 509 510 511 512 513 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 505 def access_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:access', ) command.response_representation = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#access_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::AccessSecretVersionResponse
Accesses a SecretVersion. This call returns the secret data. projects/*/
secrets/*/versions/latest is an alias to the most recently created
SecretVersion.
1071 1072 1073 1074 1075 1076 1077 1078 1079 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1071 def access_project_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}:access', ) command.response_representation = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::AccessSecretVersionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_project_location_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 159 def add_project_location_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:addVersion', ) command.request_representation = Google::Apis::SecretmanagerV1::AddSecretVersionRequest::Representation command.request_object = add_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Creates a new SecretVersion containing secret data and attaches it to an existing Secret.
725 726 727 728 729 730 731 732 733 734 735 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 725 def add_project_secret_version(parent, add_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}:addVersion', ) command.request_representation = Google::Apis::SecretmanagerV1::AddSecretVersionRequest::Representation command.request_object = add_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 197 def create_project_location_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/secrets', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['parent'] = parent unless parent.nil? command.query['secretId'] = secret_id unless secret_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Creates a new Secret containing no SecretVersions.
763 764 765 766 767 768 769 770 771 772 773 774 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 763 def create_project_secret(parent, secret_object = nil, secret_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/secrets', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['parent'] = parent unless parent.nil? command.query['secretId'] = secret_id unless secret_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 235 def delete_project_location_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Empty::Representation command.response_class = Google::Apis::SecretmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Empty
Deletes a Secret.
801 802 803 804 805 806 807 808 809 810 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 801 def delete_project_secret(name, etag: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Empty::Representation command.response_class = Google::Apis::SecretmanagerV1::Empty command.params['name'] = name unless name.nil? command.query['etag'] = etag unless etag.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#destroy_project_location_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion. Sets the state of the SecretVersion to DESTROYED and irrevocably destroys the secret data.
539 540 541 542 543 544 545 546 547 548 549 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 539 def destroy_project_location_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:destroy', ) command.request_representation = Google::Apis::SecretmanagerV1::DestroySecretVersionRequest::Representation command.request_object = destroy_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Destroys a SecretVersion. Sets the state of the SecretVersion to DESTROYED and irrevocably destroys the secret data.
1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1105 def destroy_secret_version(name, destroy_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:destroy', ) command.request_representation = Google::Apis::SecretmanagerV1::DestroySecretVersionRequest::Representation command.request_object = destroy_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_project_location_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion. Sets the state of the SecretVersion to DISABLED.
574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 574 def disable_project_location_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:disable', ) command.request_representation = Google::Apis::SecretmanagerV1::DisableSecretVersionRequest::Representation command.request_object = disable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Disables a SecretVersion. Sets the state of the SecretVersion to DISABLED.
1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1140 def disable_secret_version(name, disable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:disable', ) command.request_representation = Google::Apis::SecretmanagerV1::DisableSecretVersionRequest::Representation command.request_object = disable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_project_location_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion. Sets the state of the SecretVersion to ENABLED.
609 610 611 612 613 614 615 616 617 618 619 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 609 def enable_project_location_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enable', ) command.request_representation = Google::Apis::SecretmanagerV1::EnableSecretVersionRequest::Representation command.request_object = enable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Enables a SecretVersion. Sets the state of the SecretVersion to ENABLED.
1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1175 def enable_secret_version(name, enable_secret_version_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:enable', ) command.request_representation = Google::Apis::SecretmanagerV1::EnableSecretVersionRequest::Representation command.request_object = enable_secret_version_request_object command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Location
Gets information about a location.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 75 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Location::Representation command.response_class = Google::Apis::SecretmanagerV1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
267 268 269 270 271 272 273 274 275 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 267 def get_project_location_secret(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret. Returns empty policy if the secret exists and does not have a policy set.
311 312 313 314 315 316 317 318 319 320 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 311 def get_project_location_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion. projects/*/secrets/*/versions/latest is
an alias to the most recently created SecretVersion.
645 646 647 648 649 650 651 652 653 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 645 def get_project_location_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Gets metadata for a given Secret.
833 834 835 836 837 838 839 840 841 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 833 def get_project_secret(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Gets the access control policy for a secret. Returns empty policy if the secret exists and does not have a policy set.
877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 877 def get_project_secret_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_secret_version(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::SecretVersion
Gets metadata for a SecretVersion. projects/*/secrets/*/versions/latest is
an alias to the most recently created SecretVersion.
1211 1212 1213 1214 1215 1216 1217 1218 1219 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1211 def get_project_secret_version(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::SecretmanagerV1::SecretVersion::Representation command.response_class = Google::Apis::SecretmanagerV1::SecretVersion command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions. This call does not return secret data.
689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 689 def list_project_location_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/versions', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 354 def list_project_location_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/secrets', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListLocationsResponse
Lists information about the supported locations for this service. This method
can be called in two ways: * List all public locations: Use the path GET /
v1/locations. * List project-visible locations: Use the path GET /v1/
projects/project_id/locations. This may include public locations as well as
private or other locations specifically visible to the project.
122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 122 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}/locations', ) command.response_representation = Google::Apis::SecretmanagerV1::ListLocationsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretVersionsResponse
Lists SecretVersions. This call does not return secret data.
1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1255 def list_project_secret_versions(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/versions', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::ListSecretsResponse
Lists Secrets.
920 921 922 923 924 925 926 927 928 929 930 931 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 920 def list_project_secrets(parent, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/secrets', ) command.response_representation = Google::Apis::SecretmanagerV1::ListSecretsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::ListSecretsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 391 def patch_project_location_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Secret
Updates metadata of an existing Secret.
957 958 959 960 961 962 963 964 965 966 967 968 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 957 def patch_project_secret(name, secret_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.request_object = secret_object command.response_representation = Google::Apis::SecretmanagerV1::Secret::Representation command.response_class = Google::Apis::SecretmanagerV1::Secret command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret. Replaces any existing policy. Permissions on SecretVersions are enforced according to the policy set on the associated Secret.
429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 429 def set_project_location_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::SecretmanagerV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::Policy
Sets the access control policy on the specified secret. Replaces any existing policy. Permissions on SecretVersions are enforced according to the policy set on the associated Secret.
995 996 997 998 999 1000 1001 1002 1003 1004 1005 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 995 def set_secret_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::SecretmanagerV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::SecretmanagerV1::Policy::Representation command.response_class = Google::Apis::SecretmanagerV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret. If the secret does not exist, this call returns an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission- aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 468 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_secret_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::SecretmanagerV1::TestIamPermissionsResponse
Returns permissions that a caller has for the specified secret. If the secret does not exist, this call returns an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission- aware UIs and command-line tools, not for authorization checking. This operation may "fail open" without warning.
1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 |
# File 'lib/google/apis/secretmanager_v1/service.rb', line 1034 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::SecretmanagerV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |