Class: Google::Apis::SecretmanagerV1::SecretVersion
- Inherits:
-
Object
- Object
- Google::Apis::SecretmanagerV1::SecretVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/secretmanager_v1/classes.rb,
lib/google/apis/secretmanager_v1/representations.rb,
lib/google/apis/secretmanager_v1/representations.rb
Overview
A secret version resource in the Secret Manager API.
Instance Attribute Summary collapse
-
#client_specified_payload_checksum ⇒ Boolean
(also: #client_specified_payload_checksum?)
Output only.
-
#create_time ⇒ String
Output only.
-
#customer_managed_encryption ⇒ Google::Apis::SecretmanagerV1::CustomerManagedEncryptionStatus
Describes the status of customer-managed encryption.
-
#destroy_time ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#replication_status ⇒ Google::Apis::SecretmanagerV1::ReplicationStatus
The replication status of a SecretVersion.
-
#scheduled_destroy_time ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecretVersion
constructor
A new instance of SecretVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecretVersion
Returns a new instance of SecretVersion.
1179 1180 1181 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_specified_payload_checksum ⇒ Boolean Also known as: client_specified_payload_checksum?
Output only. True if payload checksum specified in SecretPayload object has
been received by SecretManagerService on SecretManagerService.AddSecretVersion.
Corresponds to the JSON property clientSpecifiedPayloadChecksum
1129 1130 1131 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1129 def client_specified_payload_checksum @client_specified_payload_checksum end |
#create_time ⇒ String
Output only. The time at which the SecretVersion was created.
Corresponds to the JSON property createTime
1135 1136 1137 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1135 def create_time @create_time end |
#customer_managed_encryption ⇒ Google::Apis::SecretmanagerV1::CustomerManagedEncryptionStatus
Describes the status of customer-managed encryption.
Corresponds to the JSON property customerManagedEncryption
1140 1141 1142 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1140 def customer_managed_encryption @customer_managed_encryption end |
#destroy_time ⇒ String
Output only. The time this SecretVersion was destroyed. Only present if state
is DESTROYED.
Corresponds to the JSON property destroyTime
1146 1147 1148 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1146 def destroy_time @destroy_time end |
#etag ⇒ String
Output only. Etag of the currently stored SecretVersion.
Corresponds to the JSON property etag
1151 1152 1153 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1151 def etag @etag end |
#name ⇒ String
Output only. The resource name of the SecretVersion in the format projects/*/
secrets/*/versions/*. SecretVersion IDs in a Secret start at 1 and are
incremented for each subsequent version of the secret.
Corresponds to the JSON property name
1158 1159 1160 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1158 def name @name end |
#replication_status ⇒ Google::Apis::SecretmanagerV1::ReplicationStatus
The replication status of a SecretVersion.
Corresponds to the JSON property replicationStatus
1163 1164 1165 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1163 def replication_status @replication_status end |
#scheduled_destroy_time ⇒ String
Optional. Output only. Scheduled destroy time for secret version. This is a
part of the Delayed secret version destroy feature. For a Secret with a valid
version destroy TTL, when a secert version is destroyed, version is moved to
disabled state and it is scheduled for destruction Version is destroyed only
after the scheduled_destroy_time.
Corresponds to the JSON property scheduledDestroyTime
1172 1173 1174 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1172 def scheduled_destroy_time @scheduled_destroy_time end |
#state ⇒ String
Output only. The current state of the SecretVersion.
Corresponds to the JSON property state
1177 1178 1179 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1177 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/google/apis/secretmanager_v1/classes.rb', line 1184 def update!(**args) @client_specified_payload_checksum = args[:client_specified_payload_checksum] if args.key?(:client_specified_payload_checksum) @create_time = args[:create_time] if args.key?(:create_time) @customer_managed_encryption = args[:customer_managed_encryption] if args.key?(:customer_managed_encryption) @destroy_time = args[:destroy_time] if args.key?(:destroy_time) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @replication_status = args[:replication_status] if args.key?(:replication_status) @scheduled_destroy_time = args[:scheduled_destroy_time] if args.key?(:scheduled_destroy_time) @state = args[:state] if args.key?(:state) end |